Stan Math Library: stan::math::fvar< T > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | Public Attributes | Friends | List of all members
stan::math::fvar< T > Struct Template Reference

`#include <fvar.hpp>`

## Public Types
typedef fvar | value_type

## Public Member Functions
T | val () const
T | tangent () const
| fvar ()
| fvar (const fvar< T > &x)
template<typename TV , typename TD >
| fvar (const TV &val, const TD &deriv)
template<typename TV >
| fvar (const TV &val)
fvar< T > & | operator+= (const fvar< T > &x2)
fvar< T > & | operator+= (double x2)
fvar< T > & | operator-= (const fvar< T > &x2)
fvar< T > & | operator-= (double x2)
fvar< T > & | operator*= (const fvar< T > &x2)
fvar< T > & | operator*= (double x2)
fvar< T > & | operator/= (const fvar< T > &x2)
fvar< T > & | operator/= (double x2)
fvar< T > & | operator++ ()
fvar< T > | operator++ (int)
fvar< T > & | operator-- ()
fvar< T > | operator-- (int)

## Public Attributes
T | val_
T | d_

## Friends
std::ostream & | operator<< (std::ostream &os, const fvar< T > &v)

## Detailed Description

### template<typename T>
struct stan::math::fvar< T >

Definition at line 13 of file fvar.hpp.

## Member Typedef Documentation

template<typename T>

typedef fvar stan::math::fvar< T >::value_type

Definition at line 20 of file fvar.hpp.

## Constructor & Destructor Documentation

template<typename T>

stan::math::fvar< T >::fvar | ( |  | ) |
| inline

Definition at line 22 of file fvar.hpp.

template<typename T>

stan::math::fvar< T >::fvar | ( | const fvar< T > & | x | ) |
| inline

Definition at line 24 of file fvar.hpp.

template<typename T>
template<typename TV , typename TD >

stan::math::fvar< T >::fvar | ( | const TV & | val,
|  | const TD & | deriv
| ) |  |
| inline

Definition at line 30 of file fvar.hpp.

template<typename T>
template<typename TV >

stan::math::fvar< T >::fvar | ( | const TV & | val | ) |
| inline

Definition at line 37 of file fvar.hpp.

## Member Function Documentation

template<typename T>

fvar<T>& stan::math::fvar< T >::operator*= | ( | const fvar< T > & | x2 | ) |
| inline

Definition at line 76 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator*= | ( | double | x2 | ) |
| inline

Definition at line 84 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator++ | ( |  | ) |
| inline

Definition at line 110 of file fvar.hpp.

template<typename T>

fvar<T> stan::math::fvar< T >::operator++ | ( | int |  | ) |
| inline

Definition at line 117 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator+= | ( | const fvar< T > & | x2 | ) |
| inline

Definition at line 46 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator+= | ( | double | x2 | ) |
| inline

Definition at line 54 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator-- | ( |  | ) |
| inline

Definition at line 125 of file fvar.hpp.

template<typename T>

fvar<T> stan::math::fvar< T >::operator-- | ( | int |  | ) |
| inline

Definition at line 131 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator-= | ( | const fvar< T > & | x2 | ) |
| inline

Definition at line 61 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator-= | ( | double | x2 | ) |
| inline

Definition at line 69 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator/= | ( | const fvar< T > & | x2 | ) |
| inline

Definition at line 94 of file fvar.hpp.

template<typename T>

fvar<T>& stan::math::fvar< T >::operator/= | ( | double | x2 | ) |
| inline

Definition at line 102 of file fvar.hpp.

template<typename T>

T stan::math::fvar< T >::tangent | ( |  | ) | const
| inline

Definition at line 18 of file fvar.hpp.

template<typename T>

T stan::math::fvar< T >::val | ( |  | ) | const
| inline

Definition at line 17 of file fvar.hpp.

## Friends And Related Function Documentation

template<typename T>

std::ostream& operator<< | ( | std::ostream & | os,
|  | const fvar< T > & | v
| ) |  |
| friend

Definition at line 139 of file fvar.hpp.

## Member Data Documentation

template<typename T>

T stan::math::fvar< T >::d_

Definition at line 15 of file fvar.hpp.

template<typename T>

T stan::math::fvar< T >::val_

Definition at line 14 of file fvar.hpp.

The documentation for this struct was generated from the following file:

- stan/math/fwd/core/fvar.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.